diff --git a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_field_filters.yml b/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_field_filters.yml
index 5b4a6bf..da89820 100644
--- a/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_field_filters.yml
+++ b/core/modules/comment/tests/modules/comment_test_views/test_views/views.view.test_field_filters.yml
@@ -149,7 +149,7 @@ display:
       arguments: {  }
       field_langcode: '***LANGUAGE_language_content***'
       field_langcode_add_to_query: null
-      rendering_language: translation_language_renderer
+      rendering_language: '***LANGUAGE_entity_translation***'
   page_bf:
     display_plugin: page
     id: page_bf
diff --git a/core/modules/field/src/Plugin/views/field/Field.php b/core/modules/field/src/Plugin/views/field/Field.php
index 7fdc28b..5c57f4d 100644
--- a/core/modules/field/src/Plugin/views/field/Field.php
+++ b/core/modules/field/src/Plugin/views/field/Field.php
@@ -295,15 +295,11 @@ public function query($use_groupby = FALSE) {
       // If we are grouping by something on this field, we want to group by
       // the displayed value, which is translated. So, we need to figure out
       // which language should be used to translate the value. See also
-      // $this->field_langcode().
+      // $this->field_langcode_available().
       $field = $field_definition;
       if ($field->isTranslatable() && !empty($this->view->display_handler->options['field_langcode_add_to_query'])) {
         $column = $this->tableAlias . '.langcode';
-        $langcode = $this->view->display_handler->options['field_langcode'];
-        $substitutions = static::queryLanguageSubstitutions();
-        if (isset($substitutions[$langcode])) {
-          $langcode = $substitutions[$langcode];
-        }
+        $langcode = $this->field_langcode();
         $placeholder = $this->placeholder();
         $langcode_fallback_candidates = $this->languageManager->getFallbackCandidates(array('langcode' => $langcode, 'operation' => 'views_query', 'data' => $this));
         $this->query->addWhereExpression(0, "$column IN($placeholder) OR $column IS NULL", array($placeholder => $langcode_fallback_candidates));
@@ -785,7 +781,7 @@ public function getItems(ResultRow $values) {
   function process_entity(EntityInterface $entity) {
     $processed_entity = clone $entity;
 
-    $langcode = $this->field_langcode($processed_entity);
+    $langcode = $this->field_langcode_available($processed_entity);
     $processed_entity = $processed_entity->getTranslation($langcode);
 
     // If we are grouping, copy our group fields into the cloned entity.
@@ -916,13 +912,9 @@ protected function addSelfTokens(&$tokens, $item) {
    * Return the language code of the language the field should be displayed in,
    * according to the settings.
    */
-  function field_langcode(EntityInterface $entity) {
+  function field_langcode_available(EntityInterface $entity) {
     if ($this->getFieldDefinition()->isTranslatable()) {
-      $langcode = $this->view->display_handler->options['field_langcode'];
-      $substitutions = static::queryLanguageSubstitutions();
-      if (isset($substitutions[$langcode])) {
-        $langcode = $substitutions[$langcode];
-      }
+      $langcode = $this->field_langcode();
 
       // Give the Entity Field API a chance to fallback to a different language
       // (or LanguageInterface::LANGCODE_NOT_SPECIFIED), in case the field has
@@ -939,6 +931,26 @@ function field_langcode(EntityInterface $entity) {
   }
 
   /**
+   * Resolve the language code to be used for fields.
+   *
+   * @return string
+   *   Language code to be used.
+   */
+  protected function field_langcode() {
+    $langcode = $this->view->display_handler->options['rendering_language'];
+    $substitutions = static::queryLanguageSubstitutions();
+    $substitutions += array(
+      // @todo Backwards compatible fallback, needs to be implemented.
+      '***LANGUAGE_entity_translation***' => $this->languageManager->getCurrentLanguage(LanguageInterface::TYPE_CONTENT),
+      '***LANGUAGE_entity_default***' => LanguageInterface::LANGCODE_DEFAULT,
+    );
+    if (isset($substitutions[$langcode])) {
+      $langcode = $substitutions[$langcode];
+    }
+    return $langcode;
+  }
+
+  /**
    * {@inheritdoc}
    */
   public function calculateDependencies() {
diff --git a/core/modules/node/src/Tests/NodeTranslationUITest.php b/core/modules/node/src/Tests/NodeTranslationUITest.php
index 153e87c..a9e47c3 100644
--- a/core/modules/node/src/Tests/NodeTranslationUITest.php
+++ b/core/modules/node/src/Tests/NodeTranslationUITest.php
@@ -235,7 +235,7 @@ function testTranslationRendering() {
     // Enable the translation language renderer.
     $view = \Drupal::entityManager()->getStorage('view')->load('frontpage');
     $display = &$view->getDisplay('default');
-    $display['display_options']['rendering_language'] = 'translation_language_renderer';
+    $display['display_options']['rendering_language'] = '***LANGUAGE_entity_translation***';
     $view->save();
 
     // Need to check from the beginning, including the base_path, in the url
diff --git a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_field_filters.yml b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_field_filters.yml
index d23420b..e48e6c2 100644
--- a/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_field_filters.yml
+++ b/core/modules/node/tests/modules/node_test_views/test_views/views.view.test_field_filters.yml
@@ -164,7 +164,7 @@ display:
       arguments: {  }
       field_langcode: '***LANGUAGE_language_content***'
       field_langcode_add_to_query: null
-      rendering_language: translation_language_renderer
+      rendering_language: '***LANGUAGE_entity_translation***'
   page_bf:
     display_plugin: page
     id: page_bf
diff --git a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_default_argument_test.yml b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_default_argument_test.yml
index c65d9c9..a3b5f5f 100644
--- a/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_default_argument_test.yml
+++ b/core/modules/taxonomy/tests/modules/taxonomy_test_views/test_views/views.view.taxonomy_default_argument_test.yml
@@ -163,4 +163,4 @@ display:
           entity_field: tid
       field_langcode: '***LANGUAGE_site_default***'
       field_langcode_add_to_query: null
-      rendering_language: translation_language_renderer
+      rendering_language: '***LANGUAGE_entity_translation***'
diff --git a/core/modules/views/src/Entity/Render/CurrentLanguageRenderer.php b/core/modules/views/src/Entity/Render/CurrentLanguageRenderer.php
index fb91787..454adcc 100644
--- a/core/modules/views/src/Entity/Render/CurrentLanguageRenderer.php
+++ b/core/modules/views/src/Entity/Render/CurrentLanguageRenderer.php
@@ -21,6 +21,7 @@ class CurrentLanguageRenderer extends RendererBase {
    *   The result row.
    */
   protected function getLangcode(ResultRow $row) {
+    return $this->langcode;
   }
 
 }
diff --git a/core/modules/views/src/Entity/Render/RendererBase.php b/core/modules/views/src/Entity/Render/RendererBase.php
index c74964d..ef8e388 100644
--- a/core/modules/views/src/Entity/Render/RendererBase.php
+++ b/core/modules/views/src/Entity/Render/RendererBase.php
@@ -40,6 +40,13 @@
   protected $entityType;
 
   /**
+   * A specific language code for rendering if available.
+   *
+   * @var string|null
+   */
+  protected $langcode;
+
+  /**
    * Contains an array of render arrays, one for each rendered entity.
    *
    * @var array
@@ -55,11 +62,14 @@
    *   The language manager.
    * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
    *   The entity type.
+   * @param string|null $langcode
+   *   A specific language code to set, if available.
    */
-  public function __construct(ViewExecutable $view, LanguageManagerInterface $language_manager, EntityTypeInterface $entity_type) {
+  public function __construct(ViewExecutable $view, LanguageManagerInterface $language_manager, EntityTypeInterface $entity_type, $langcode = NULL) {
     $this->view = $view;
     $this->languageManager = $language_manager;
     $this->entityType = $entity_type;
+    $this->langcode = $langcode;
   }
 
   /**
diff --git a/core/modules/views/src/Plugin/views/display/DisplayPluginBase.php b/core/modules/views/src/Plugin/views/display/DisplayPluginBase.php
index a49740d..4fb3d74 100644
--- a/core/modules/views/src/Plugin/views/display/DisplayPluginBase.php
+++ b/core/modules/views/src/Plugin/views/display/DisplayPluginBase.php
@@ -215,11 +215,11 @@ public function initDisplay(ViewExecutable $view, array &$display, array &$optio
       $this->unpackOptions($this->options, $options);
     }
 
-    // Convert the field_langcode and field_language_add_to_query settings.
-    $field_langcode = $this->getOption('field_langcode');
+    // Convert the rendering_language and field_language_add_to_query settings.
+    $field_langcode = $this->getOption('rendering_language');
     $field_language_add_to_query = $this->getOption('field_language_add_to_query');
     if (isset($field_langcode)) {
-      $this->setOption('field_langcode', $field_langcode);
+      $this->setOption('rendering_language', $field_langcode);
       $this->setOption('field_langcode_add_to_query', $field_language_add_to_query);
       $changed = TRUE;
     }
@@ -595,15 +595,12 @@ protected function defineOptions() {
       'group_by' => array(
         'default' => FALSE,
       ),
-      'field_langcode' => array(
-        'default' => '***LANGUAGE_language_content***',
+      'rendering_language' => array(
+        'default' => '***LANGUAGE_entity_translation***',
       ),
       'field_langcode_add_to_query' => array(
         'default' => TRUE,
       ),
-      'rendering_language' => array(
-        'default' => 'translation_language_renderer',
-      ),
 
       // These types are all plugins that can have individual settings
       // and therefore need special handling.
@@ -1278,15 +1275,9 @@ public function optionsSummary(&$categories, &$options) {
       $rendering_language_options = $this->buildRenderingLanguageOptions();
       $options['rendering_language'] = array(
         'category' => 'language',
-        'title' => $this->t('Entity Language'),
+        'title' => $this->t('Rendering Language'),
         'value' => $rendering_language_options[$this->getOption('rendering_language')],
-      );
-      $language_options = $this->listLanguages(LanguageInterface::STATE_ALL | LanguageInterface::STATE_SITE_DEFAULT | PluginBase::INCLUDE_NEGOTIATED);
-      $options['field_langcode'] = array(
-        'category' => 'language',
-        'title' => $this->t('Field Language'),
-        'value' => $language_options[$this->getOption('field_langcode')],
-        'desc' => $this->t('All fields that support translations will be displayed in the selected language.'),
+        'desc' => $this->t('All content that supports translations will be displayed in the selected language.'),
       );
     }
 
@@ -1636,38 +1627,22 @@ public function buildOptionsForm(&$form, FormStateInterface $form_state) {
           $this->view->query->buildOptionsForm($form['query']['options'], $form_state);
         }
         break;
-      case 'field_langcode':
-        $form['#title'] .= $this->t('Field Language');
-        if ($this->isBaseTableTranslatable()) {
-          $languages = $this->listLanguages(LanguageInterface::STATE_ALL | LanguageInterface::STATE_SITE_DEFAULT | PluginBase::INCLUDE_NEGOTIATED);
-
-          $form['field_langcode'] = array(
-            '#type' => 'select',
-            '#title' => $this->t('Field Language'),
-            '#description' => $this->t('All fields which support translations will be displayed in the selected language.'),
-            '#options' => $languages,
-            '#default_value' => $this->getOption('field_langcode'),
-          );
-          $form['field_langcode_add_to_query'] = array(
-            '#type' => 'checkbox',
-            '#title' => $this->t('When needed, add the field language condition to the query'),
-            '#default_value' => $this->getOption('field_langcode_add_to_query'),
-          );
-        }
-        else {
-          $form['field_language']['#markup'] = $this->t("You don't have translatable entity types.");
-        }
-        break;
       case 'rendering_language':
-        $form['#title'] .= $this->t('Entity Language');
+        $form['#title'] .= $this->t('Rendering language');
         if ($this->isBaseTableTranslatable()) {
           $options = $this->buildRenderingLanguageOptions();
           $form['rendering_language'] = array(
             '#type' => 'select',
             '#options' => $options,
-            '#title' => $this->t('Entity language'),
+            '#title' => $this->t('Rendering language'),
+            '#description' => $this->t('All content that supports translations will be displayed in the selected language.'),
             '#default_value' => $this->getOption('rendering_language'),
           );
+          $form['field_langcode_add_to_query'] = array(
+            '#type' => 'checkbox',
+            '#title' => $this->t('When needed, add the field language condition to the query'),
+            '#default_value' => $this->getOption('field_langcode_add_to_query'),
+          );
         }
         else {
           $form['rendering_language']['#markup'] = $this->t("You don't have translatable entity types.");
@@ -1986,12 +1961,9 @@ public function submitOptionsForm(&$form, FormStateInterface $form_state) {
       case 'group_by':
         $this->setOption($section, $form_state->getValue($section));
         break;
-      case 'field_langcode':
-        $this->setOption('field_langcode', $form_state->getValue('field_langcode'));
-        $this->setOption('field_langcode_add_to_query', $form_state->getValue('field_langcode_add_to_query'));
-        break;
       case 'rendering_language':
         $this->setOption('rendering_language', $form_state->getValue('rendering_language'));
+        $this->setOption('field_langcode_add_to_query', $form_state->getValue('field_langcode_add_to_query'));
         break;
       case 'use_ajax':
       case 'hide_attachment_summary':
@@ -2702,11 +2674,7 @@ public function getExtenders() {
    */
   protected function buildRenderingLanguageOptions() {
     // @todo Consider making these plugins. See https://drupal.org/node/2173811.
-    return array(
-      'current_language_renderer' => $this->t('Current language'),
-      'default_language_renderer' => $this->t('Default language'),
-      'translation_language_renderer' => $this->t('Translation language'),
-    );
+    return $this->listLanguages(LanguageInterface::STATE_CONFIGURABLE | LanguageInterface::STATE_SITE_DEFAULT | PluginBase::INCLUDE_NEGOTIATED | PluginBase::INCLUDE_ENTITY);
   }
 
   /**
diff --git a/core/modules/views/src/Plugin/views/row/EntityRow.php b/core/modules/views/src/Plugin/views/row/EntityRow.php
index 159a1d4..69b53de 100644
--- a/core/modules/views/src/Plugin/views/row/EntityRow.php
+++ b/core/modules/views/src/Plugin/views/row/EntityRow.php
@@ -153,8 +153,28 @@ public function summaryTitle() {
    */
   protected function getRenderer() {
     if (!isset($this->renderer)) {
-      $class = '\Drupal\views\Entity\Render\\' . Container::camelize($this->displayHandler->getOption('rendering_language'));
-      $this->renderer = new $class($this->view, $this->languageManager, $this->entityType);
+      $renderer = $this->displayHandler->getOption('rendering_language');
+      $langcode = NULL;
+      $dynamic_renderers = array(
+        '***LANGUAGE_entity_translation***' => 'TranslationLanguageRenderer',
+        '***LANGUAGE_entity_default***' => 'DefaultLanguageRenderer',
+      );
+      if (isset($dynamic_renderers[$renderer])) {
+        // Dynamic language set based on result rows or instance defaults.
+        $renderer = $dynamic_renderers[$renderer];
+      }
+      else {
+        if (strpos($renderer, '***LANGUAGE_') !== FALSE) {
+          $langcode = static::queryLanguageSubstitutions()[$renderer];
+        }
+        else {
+          // Specific langcode set.
+          $langcode = $renderer;
+        }
+        $renderer = 'CurrentLanguageRenderer';
+      }
+      $class = '\Drupal\views\Entity\Render\\' . $renderer;
+      $this->renderer = new $class($this->view, $this->languageManager, $this->entityType, $langcode);
     }
     return $this->renderer;
   }
diff --git a/core/modules/views/src/Tests/Entity/RowEntityRenderersTest.php b/core/modules/views/src/Tests/Entity/RowEntityRenderersTest.php
index 0c2adca..b2a6f5c 100644
--- a/core/modules/views/src/Tests/Entity/RowEntityRenderersTest.php
+++ b/core/modules/views/src/Tests/Entity/RowEntityRenderersTest.php
@@ -109,7 +109,7 @@ public function testRenderers() {
       $values[2]['en'],
       $values[2]['en'],
     );
-    $this->assertTranslations('current_language_renderer', $expected, 'The current language renderer behaves as expected.');
+    $this->assertTranslations('***LANGUAGE_language_content***', $expected, 'The current language renderer behaves as expected.');
 
     $expected = array(
       $values[0]['en'],
@@ -122,7 +122,7 @@ public function testRenderers() {
       $values[2]['l1'],
       $values[2]['l1'],
     );
-    $this->assertTranslations('default_language_renderer', $expected, 'The default language renderer behaves as expected.');
+    $this->assertTranslations('***LANGUAGE_entity_default***', $expected, 'The default language renderer behaves as expected.');
 
     $expected = array(
       $values[0]['en'],
@@ -135,7 +135,33 @@ public function testRenderers() {
       $values[2]['l0'],
       $values[2]['l1'],
     );
-    $this->assertTranslations('translation_language_renderer', $expected, 'The translation language renderer behaves as expected.');
+    $this->assertTranslations('***LANGUAGE_entity_translation***', $expected, 'The translation language renderer behaves as expected.');
+
+    $expected = array(
+      $values[0][$this->langcodes[0]],
+      $values[0][$this->langcodes[0]],
+      $values[0][$this->langcodes[0]],
+      $values[1][$this->langcodes[0]],
+      $values[1][$this->langcodes[0]],
+      $values[1][$this->langcodes[0]],
+      $values[2][$this->langcodes[0]],
+      $values[2][$this->langcodes[0]],
+      $values[2][$this->langcodes[0]],
+    );
+    $this->assertTranslations('***LANGUAGE_site_default***', $expected, 'The site default language renderer behaves as expected.');
+
+    $expected = array(
+      $values[0]['l0'],
+      $values[0]['l0'],
+      $values[0]['l0'],
+      $values[1]['l0'],
+      $values[1]['l0'],
+      $values[1]['l0'],
+      $values[2]['l0'],
+      $values[2]['l0'],
+      $values[2]['l0'],
+    );
+    $this->assertTranslations('l0', $expected, 'The language specific renderer behaves as expected.');
   }
 
   /**
diff --git a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_row_renderers.yml b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_row_renderers.yml
index 9c7307d..c544913 100644
--- a/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_row_renderers.yml
+++ b/core/modules/views/tests/modules/views_test_config/test_views/views.view.test_entity_row_renderers.yml
@@ -41,4 +41,4 @@ display:
           entity_field: title
       field_langcode: '***LANGUAGE_language_content***'
       field_langcode_add_to_query: null
-      rendering_language: translation_language_renderer
+      rendering_language: '***LANGUAGE_entity_translation***'
diff --git a/core/modules/views/src/Plugin/views/PluginBase.php b/core/modules/views/src/Plugin/views/PluginBase.php
index 831d608..a0ee031 100644
--- a/core/modules/views/src/Plugin/views/PluginBase.php
+++ b/core/modules/views/src/Plugin/views/PluginBase.php
@@ -52,6 +52,13 @@
   const INCLUDE_NEGOTIATED = 16;
 
   /**
+   * Include entity row languages when listing languages.
+   *
+   * @see \Drupal\views\Plugin\views\PluginBase::listLanguages()
+   */
+  const INCLUDE_ENTITY = 32;
+
+  /**
    * Query string to indicate the site default language.
    *
    * @see \Drupal\Core\Language\LanguageInterface::LANGCODE_DEFAULT
@@ -439,16 +446,25 @@ public function getProvider() {
    *     note that this is not included in STATE_ALL.
    *   - \Drupal\views\Plugin\views\PluginBase::INCLUDE_NEGOTIATED: Add
    *     negotiated language types.
+   *   - \Drupal\views\Plugin\views\PluginBase::INCLUDE_ENTITY: Add
+   *     entity row language types. Note that these are only supported for
+   *     display options, not substituted in queries.
    *
    * @return array
    *   An array of language names, keyed by the language code. Negotiated and
    *   special languages have special codes that are substituted in queries by
-   *   static::queryLanguageSubstitutions().
+   *   PluginBase::queryLanguageSubstitutions().
    */
   protected function listLanguages($flags = LanguageInterface::STATE_ALL) {
     $manager = \Drupal::languageManager();
     $list = array();
 
+    // The entity languages should come first, if requested.
+    if ($flags & PluginBase::INCLUDE_ENTITY) {
+      $list['***LANGUAGE_entity_translation***'] = $this->t('Content language of view row');
+      $list['***LANGUAGE_entity_default***'] = $this->t('Default language of content in view row');
+    }
+
     // The Language Manager class takes care of the STATE_SITE_DEFAULT case.
     // It comes in with ID set to LanguageInterface::LANGCODE_SITE_DEFAULT.
     // Since this is not a real language, surround it by '***LANGUAGE_...***',
@@ -470,7 +486,7 @@ protected function listLanguages($flags = LanguageInterface::STATE_ALL) {
         // IDs by '***LANGUAGE_...***', to avoid query collisions.
         if (isset($type['name'])) {
           $id = '***LANGUAGE_' . $id . '***';
-          $list[$id] = $this->t('Language selected for !type', array('!type' => $type['name']));
+          $list[$id] = $this->t('Page language selected by !type methods', array('!type' => $type['name']));
         }
       }
     }
@@ -482,7 +498,7 @@ protected function listLanguages($flags = LanguageInterface::STATE_ALL) {
    * Returns substitutions for Views queries for languages.
    *
    * This is needed so that the language options returned by
    * $this->listLanguages() are able to be used in queries. It is called
    * by the Views module implementation of hook_views_query_substitutions()
    * to get the language-related substitutions.
    *
@@ -482,7 +498,7 @@ protected function listLanguages($flags = LanguageInterface::STATE_ALL) {
    *
    * This is needed so that the language options returned by
-   * $this->listLanguages() are able to be used in queries. It is called
+   * PluginBase::listLanguages() are able to be used in queries. It is called
    * by the Views module implementation of hook_views_query_substitutions()
    * to get the language-related substitutions.
diff --git a/core/modules/views_ui/src/Tests/ViewEditTest.php b/core/modules/views_ui/src/Tests/ViewEditTest.php
index 1dd7e0e..5d5a476 100644
--- a/core/modules/views_ui/src/Tests/ViewEditTest.php
+++ b/core/modules/views_ui/src/Tests/ViewEditTest.php
@@ -100,9 +100,10 @@ public function testEditFormLanguageOptions() {
     foreach ($test_views as $view_name => $display) {
       $this->drupalGet('admin/structure/views/view/' . $view_name);
       $this->assertResponse(200);
-      $langcode_url = 'admin/structure/views/nojs/display/' . $view_name . '/' . $display . '/field_langcode';
+      $langcode_url = 'admin/structure/views/nojs/display/' . $view_name . '/' . $display . '/rendering_language';
       $this->assertNoLinkByHref($langcode_url);
-      $this->assertNoLink(t('Language selected for !type', array('!type' => t('Content'))));
+      $this->assertNoLink(t('Page language selected by !type methods', array('!type' => t('Content'))));
+      $this->assertNoLink(t('Content language of view row'));
     }
 
     // Make the site multilingual and test the options again.
@@ -111,18 +112,20 @@ public function testEditFormLanguageOptions() {
     $this->resetAll();
     $this->rebuildContainer();
 
     // Language options should now exist with content language defaults.
     foreach ($test_views as $view_name => $display) {
       $this->drupalGet('admin/structure/views/view/' . $view_name);
       $this->assertResponse(200);
-      $langcode_url = 'admin/structure/views/nojs/display/' . $view_name . '/' . $display . '/field_langcode';
+      $langcode_url = 'admin/structure/views/nojs/display/' . $view_name . '/' . $display . '/rendering_language';
       if ($view_name == 'test_view') {
         $this->assertNoLinkByHref($langcode_url);
-        $this->assertNoLink(t('Language selected for !type', array('!type' => t('Content'))));
+        $this->assertNoLink(t('Page language selected by !type methods', array('!type' => t('Content'))));
+        $this->assertNoLink(t('Content language of view row'));
       }
       else {
         $this->assertLinkByHref($langcode_url);
-        $this->assertLink(t('Language selected for !type', array('!type' => t('Content'))));
+        $this->assertNoLink(t('Page language selected by !type methods', array('!type' => t('Content'))));
+        $this->assertLink(t('Content language of view row'));
       }
 
       $this->drupalGet($langcode_url);
@@ -131,7 +134,7 @@ public function testEditFormLanguageOptions() {
         $this->assertText(t("You don't have translatable entity types."));
       }
       else {
-        $this->assertFieldByName('field_langcode', '***LANGUAGE_language_content***');
+        $this->assertFieldByName('rendering_language', '***LANGUAGE_entity_translation***');
         $this->assertFieldByName('field_langcode_add_to_query', TRUE);
       }
     }
@@ -111,18 +112,20 @@ public function testEditFormLanguageOptions() {
     $this->rebuildContainer();
 
-    // Language options should now exist with content language defaults.
+    // Language options should now exist with entity language the default.
     foreach ($test_views as $view_name => $display) {
       $this->drupalGet('admin/structure/views/view/' . $view_name);
